import os

import pytest
import qiskit

import bluequbit


@pytest.mark.skipif(
    "BLUEQUBIT_STRESS_TESTS" not in os.environ, reason="Requires env variable to be set"
)
def test_gpu_job():
    dq_client = bluequbit.BQClient()
    # time_now = "2022-10-19T13:05:17.917290Z"
    n = 10  # will get to GPU1
    qc_qiskit = qiskit.QuantumCircuit(n)
    for i in range(n):
        qc_qiskit.h(i)
    qc_qiskit.measure_all()

    job_result = dq_client.run(qc_qiskit, job_name="testing_gpu_qiskit", device="gpu")
    print(job_result)

    assert job_result.run_status == "COMPLETED"


# @pytest.mark.skipif(
#     "BLUEQUBIT_STRESS_TESTS" not in os.environ, reason="Requires env variable to be set"
# )
# def test_gpu_job_cirq():
#     import cirq
#     dq_client = bluequbit.BQClient()
#     n = 33
#     qc = cirq.Circuit()
#     qs = cirq.LineQubit.range(n)
#     for i in range(n):
#         qc.append(cirq.H(qs[i]))
#     qc.append(cirq.measure(qs))
#     job_result = dq_client.run(qc, job_name="testing_gpu_cirq", device="gpu")
#     assert job_result.run_status == "COMPLETED"



import numpy as np
import qiskit

import bluequbit


def test_job_estimation():
    dq_client = bluequbit.BQClient()
    qc_qiskit = qiskit.QuantumCircuit(2)
    qc_qiskit.h(0)
    qc_qiskit.x(1)
    results = dq_client.estimate(qc_qiskit)
    assert results.estimated_runtime == 100


def test_job_estimation_large():
    dq_client = bluequbit.BQClient()
    qc = qiskit.QuantumCircuit(24)
    qc.x(np.arange(24))
    results = dq_client.estimate(qc)
    assert results.estimated_runtime == 187
    # assert results.device == "qsim_simulator"
    assert results.num_qubits == 24
    assert (
        results.warning_message
        == "This is just an estimate; the actual runtime may be less or more."
    )


def test_job_estimate_validation_too_many_qubits():
    # Too many qubits
    dq_client = bluequbit.BQClient()
    qc = qiskit.QuantumCircuit(38)
    qc.x(np.arange(38))
    result = dq_client.estimate(qc)
    expected_message = "Circuit contains more than 37 qubits, which is not supported."
    assert expected_message in result.error_message

    result = dq_client.run(qc)
    print(result)
    assert expected_message in result.error_message
